from enum import Enum


class FileTypes(Enum):
    _3G2 = "3g2"
    _3GP = "3gp"
    _7Z = "7z"
    _8SV = "8sv"
    _8SVX = "8svx"
    ACBM = "acbm"
    AIF = "aif"
    AIFC = "aifc"
    AIFF = "aiff"
    ANBM = "anbm"
    ANIM = "anim"
    APK = "apk"
    ASF = "asf"
    AVI = "avi"
    BAC = "bac"
    BIN = "bin"
    BMP = "bmp"
    BPG = "bpg"
    BZ2 = "bz2"
    CAB = "cab"
    CIN = "cin"
    CLASS = "class"
    CMUS = "cmus"
    CR2 = "cr2"
    CRX = "crx"
    CSS = "css"
    CWK = "cwk"
    DAT = "dat"
    DBA = "dba"
    DCM = "dcm"
    DEB = "deb"
    DER = "der"
    DEX = "dex"
    DIB = "dib"
    DJV = "djv"
    DJVU = "djvu"
    DMG = "dmg"
    DOC = "doc"
    DOCX = "docx"
    DPX = "dpx"
    EXE = "exe"
    EXR = "exr"
    FAXX = "faxx"
    FH8 = "fh8"
    FITS = "fits"
    FLAC = "flac"
    FLIF = "flif"
    FTXT = "ftxt"
    GIF = "gif"
    GZ = "gz"
    IBM = "ibm"
    ICO = "ico"
    IDX = "idx"
    IFF = "iff"
    ILBM = "ilbm"
    ISO = "iso"
    JAR = "jar"
    JPEG = "jpeg"
    JPG = "jpg"
    LBM = "lbm"
    LEP = "lep"
    LZ = "lz"
    LZ4 = "lz4"
    MID = "mid"
    MIDI = "midi"
    MK3D = "mk3d"
    MKA = "mka"
    MKS = "mks"
    MKV = "mkv"
    MLV = "mlv"
    MP3 = "mp3"
    MSG = "msg"
    MUS = "mus"
    NES = "nes"
    ODP = "odp"
    ODS = "ods"
    ODT = "odt"
    OGA = "oga"
    OGG = "ogg"
    OGV = "ogv"
    PDB = "pdb"
    PDF = "pdf"
    PIC = "pic"
    PIF = "pif"
    PNG = "png"
    PPT = "ppt"
    PPTX = "pptx"
    PS = "ps"
    PSD = "psd"
    RAR = "rar"
    RPM = "rpm"
    SEA = "sea"
    SMU = "smu"
    SMUS = "smus"
    SND = "snd"
    STG = "stg"
    SVX = "svx"
    SWF = "swf"
    TAR = "tar"
    TAR_GZ = "tar_gz"
    TAR_Z = "tar_z"
    TDA = "tda"
    TIF = "tif"
    TIFF = "tiff"
    TOAST = "toast"
    TOX = "tox"
    TXT = "txt"
    VMDK = "vmdk"
    VSDX = "vsdx"
    WASM = "wasm"
    WAV = "wav"
    WEBM = "webm"
    WEBP = "webp"
    WMA = "wma"
    WMV = "wmv"
    WOFF = "woff"
    WOFF2 = "woff2"
    XAR = "xar"
    XLS = "xls"
    XLSX = "xlsx"
    XML = "xml"
    YTR = "ytr"
    YUV = "yuv"
    YUVN = "yuvn"
    Z = "z"
    ZIP = "zip"
